@@ -6,8 +6,8 @@ logger = logging.getLogger(__name__)
 def idps_post_run(self) -> None:
     try:
         url = self.overrideinfo["url"]
-        retriever = self.get_reader(prefix="idps_override")
-        json = retriever.download_json(url)
+        retriever = self.get_reader()
+        json = retriever.download_json(url, file_prefix="idps_override")
         number_idps = int(json["data"][0]["individuals"])
         index = self.get_headers("national")[1].index("#affected+displaced")
         values = self.get_values("national")[index]
